pub struct HostPreferences { /* private fields */ }Expand description
Per-host renderer preference cache. Cheap to clone (Arc inside).
Implementations
Sourceimpl HostPreferences
impl HostPreferences
pub fn new(capacity: u64, ttl: Duration) -> Self
pub fn with_defaults() -> Self
Sourcepub async fn record_failure(
&self,
host: &str,
kind: &FailoverErrorKind,
) -> Option<RendererKind>
pub async fn record_failure( &self, host: &str, kind: &FailoverErrorKind, ) -> Option<RendererKind>
Record a failure for host (will be normalized). Returns the
promotion target if this call promoted the host, else None.
Sourcepub async fn record_success(&self, host: &str)
pub async fn record_success(&self, host: &str)
Record a successful render for host (will be normalized).
Sourcepub async fn preferred(&self, host: &str) -> Option<RendererKind>
pub async fn preferred(&self, host: &str) -> Option<RendererKind>
Returns the preferred renderer for host if a promotion is in
effect, else None (caller falls back to default chain).
Sourcepub async fn reset_host(&self, host: &str)
pub async fn reset_host(&self, host: &str)
Clear preference state for a specific host (will be normalized).